#include "io430.h"

#define BUT1 (!(PBIN & BIT0))
#define BUT2 (!(PBIN & BIT1))

#define BIT15 (0x8000)

#define LED1_ON (PAOUT |= BIT15)
#define LED1_OFF (PAOUT &= ~BIT15)
#define LED1_TOGGLE (PAOUT ^= BIT15)
#define LED2_ON (PBOUT |= BIT7)
#define LED2_OFF (PBOUT &= ~BIT7)
#define LED2_TOGGLE (PBOUT ^= BIT7)


void Init_RTC(void)
{
  int timeout = 5000;

  PJSEL0 |= BIT5 + BIT4;        //Enable XT1 pins

  CSCTL0_H = 0xA5;              //CSKEY password - make all registers available for writing (user manual)
  CSCTL4 &= ~XT1OFF;            //clear bit0 in CSCTL4 register => XT1 is on
  CSCTL4 &= ~BIT6;              //
  CSCTL4 &= ~BIT7;              //clear XT1DRIVE bits in CSCTL4 register => Lowest current consumption for XT1 LF mode

  do
  {
    CSCTL5 &= ~XT1OFFG;                           // Clear XT1 fault flags
    SFRIFG1 &= ~OFIFG;                            // Clear fault flags
  }
  while (timeout && (SFRIFG1 & OFIFG));          // Test oscillator fault flag    
}

void TIMER(void)
{
  TA0CCTL0 |= CCIE;                     // CCR0 interrupt enabled
  TA0CCR0 = 32768;
  TA0CTL |= MC1 + TASSEL0 + TACLR;    
}

#pragma vector = TIMER0_A0_VECTOR
__interrupt void TIMER0_A0_ISR (void)
{
  LED2_TOGGLE;  // toggle green LED
  TA0R = 0;
}

void Delay(volatile unsigned long int Time)
{
  while(--Time);
}

int main (void)
{
  // Stop watchdog timer to prevent time out reset
  WDTCTL = WDTPW + WDTHOLD;

  // LED Init
  PADIR |= BIT15;               //LED1 - P2.7 is output
  LED1_OFF;
  PBDIR |= BIT7;                //LED2 - P3.7 is output
  LED2_OFF;

  // Buttons init
  PBDIR &= ~(BIT0 + BIT1);      // buttons - input
  PBOUT |= BIT0 + BIT1;         // pull-ups enabled
  PBREN |= BIT0 + BIT1;
  Delay(1000);

  Init_RTC ();
  TIMER ();
  __bis_SR_register(GIE);

  while (1)
  {
    if (BUT1)   // if you hold button 1
      LED1_ON;  // yellow LED is ON
    if (BUT2)   // if you hold button 2
      LED1_OFF; // yellow LED is OFF
    if ((!BUT1) && (!BUT2))     // if you don't hold any of the buttons
      LED1_TOGGLE;      // toggle yellow LED
    Delay(10000);
  }
}
